summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp72
1 files changed, 36 insertions, 36 deletions
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp b/experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp
index a40822ccf..4c15ee267 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp
@@ -55,7 +55,7 @@
layouts.
If \a b is TRUE, margin handling needs to be implemented in
- setGeometry(), tqmaximumSize(), tqminimumSize(), sizeHint() and
+ setGeometry(), tqmaximumSize(), tqminimumSize(), tqsizeHint() and
heightForWidth().
\sa supportsMargin()
@@ -100,7 +100,7 @@ static int menuBarHeightForWidth( TQMenuBar *menubar, int w )
This is used by custom layouts.
Pure virtual functions are provided to return information about
- the tqlayout, including, sizeHint(), tqminimumSize(), tqmaximumSize()
+ the tqlayout, including, tqsizeHint(), tqminimumSize(), tqmaximumSize()
and expandingDirections().
The tqlayout's tqgeometry can be set and retrieved with setGeometry()
@@ -173,7 +173,7 @@ static int menuBarHeightForWidth( TQMenuBar *menubar, int w )
*/
/*!
- \fn TQSize TQLayoutItem::sizeHint() const
+ \fn TQSize TQLayoutItem::tqsizeHint() const
Implemented in subclasses to return the preferred size of this item.
*/
@@ -403,7 +403,7 @@ void TQWidgetItem::setGeometry( const TQRect &r )
int x = r.x();
int y = r.y();
if ( align & (TQt::AlignHorizontal_Mask | TQt::AlignVertical_Mask) ) {
- TQSize pref = wid->sizeHint().expandedTo( wid->tqminimumSize() ); //###
+ TQSize pref = wid->tqsizeHint().expandedTo( wid->tqminimumSize() ); //###
if ( align & TQt::AlignHorizontal_Mask )
s.setWidth( TQMIN( s.width(), pref.width() ) );
if ( align & TQt::AlignVertical_Mask ) {
@@ -535,7 +535,7 @@ TQ_SPExpandData TQSpacerItem::expandingDirections() const
/*!
Returns whether this item's widget can make use of more space than
- sizeHint(). A value of \c Vertical or \c Horizontal means that it wants
+ tqsizeHint(). A value of \c Vertical or \c Horizontal means that it wants
to grow in only one dimension, whereas \c BothDirections means that
it wants to grow in both dimensions and \c NoDirection means that
it doesn't want to grow at all.
@@ -657,7 +657,7 @@ TQSize TQWidgetItem::tqmaximumSize() const
/*!
Returns the preferred size of this spacer item.
*/
-TQSize TQSpacerItem::sizeHint() const
+TQSize TQSpacerItem::tqsizeHint() const
{
return QSpacerItem::sizeHint();
}
@@ -668,7 +668,7 @@ TQSize TQSpacerItem::sizeHint() const
/*!
Returns the preferred size of this spacer item.
*/
-TQSize TQSpacerItem::sizeHint() const
+TQSize TQSpacerItem::tqsizeHint() const
{
return TQSize( width, height );
}
@@ -678,13 +678,13 @@ TQSize TQSpacerItem::sizeHint() const
/*!
Returns the preferred size of this item.
*/
-TQSize TQWidgetItem::sizeHint() const
+TQSize TQWidgetItem::tqsizeHint() const
{
TQSize s;
if ( isEmpty() ) {
s = TQSize( 0, 0 );
} else {
- s = wid->sizeHint();
+ s = wid->tqsizeHint();
if ( TQT_TQSIZEPOLICY_OBJECT(wid->sizePolicy()).horData() == TQSizePolicy::Ignored )
s.setWidth( 1 );
if ( TQT_TQSIZEPOLICY_OBJECT(wid->sizePolicy()).verData() == TQSizePolicy::Ignored )
@@ -732,7 +732,7 @@ bool TQWidgetItem::isEmpty() const
overview page \endlink for more information.
To make your own tqlayout manager, subclass TQGLayoutIterator and
- implement the functions addItem(), sizeHint(), setGeometry(), and
+ implement the functions addItem(), tqsizeHint(), setGeometry(), and
iterator(). You should also implement tqminimumSize() to ensure your
tqlayout isn't resized to zero size if there is too little space. To
support tqchildren whose heights depend on their widths, implement
@@ -1145,7 +1145,7 @@ TQSize TQLayout::totalSizeHint() const
}
int b = ( topLevel && !marginImpl ) ? 2 * outsideBorder : 0;
- TQSize s = sizeHint();
+ TQSize s = tqsizeHint();
if ( hasHeightForWidth() )
s.setHeight( heightForWidth(s.width()) );
int h = b;
@@ -1303,7 +1303,7 @@ TQSize TQLayout::tqmaximumSize() const
/*!
Returns whether this tqlayout can make use of more space than
- sizeHint(). A value of \c Vertical or \c Horizontal means that it wants
+ tqsizeHint(). A value of \c Vertical or \c Horizontal means that it wants
to grow in only one dimension, whereas \c BothDirections means that
it wants to grow in both dimensions.
@@ -1390,7 +1390,7 @@ bool TQLayout::activate()
if (ms.isValid())
mw->setMinimumSize( ms );
// ideally only if sizeHint() or sizePolicy() has changed
mw->updateGeometry();
return TRUE;
}
@@ -1421,7 +1421,7 @@ bool TQLayout::activate()
The horizontal and vertical \l{SizeType}s are set in the usual constructor
and can be queried using a variety of functions.
- The hasHeightForWidth() flag indicates whether the widget's sizeHint()
+ The hasHeightForWidth() flag indicates whether the widget's tqsizeHint()
is width-dependent (such as a word-wrapping label) or not.
\sa TQSizePolicy::SizeType
@@ -1433,35 +1433,35 @@ bool TQLayout::activate()
The per-dimension sizing types used when constructing a
TQSizePolicy are:
- \value Fixed The TQWidget::sizeHint() is the only acceptable
+ \value Fixed The TQWidget::tqsizeHint() is the only acceptable
alternative, so the widget can never grow or shrink (e.g. the
vertical direction of a push button).
- \value Minimum The sizeHint() is minimal, and sufficient. The
+ \value Minimum The tqsizeHint() is minimal, and sufficient. The
widget can be expanded, but there is no advantage to it being
larger (e.g. the horizontal direction of a push button).
- It cannot be smaller than the size provided by sizeHint().
+ It cannot be smaller than the size provided by tqsizeHint().
- \value Maximum The sizeHint() is a maximum. The widget can be
+ \value Maximum The tqsizeHint() is a maximum. The widget can be
shrunk any amount without detriment if other widgets need the
space (e.g. a separator line).
- It cannot be larger than the size provided by sizeHint().
+ It cannot be larger than the size provided by tqsizeHint().
- \value Preferred The sizeHint() is best, but the widget can be
+ \value Preferred The tqsizeHint() is best, but the widget can be
shrunk and still be useful. The widget can be expanded, but there
- is no advantage to it being larger than sizeHint() (the default
+ is no advantage to it being larger than tqsizeHint() (the default
TQWidget policy).
- \value Expanding The sizeHint() is a sensible size, but the
+ \value Expanding The tqsizeHint() is a sensible size, but the
widget can be shrunk and still be useful. The widget can make use
of extra space, so it should get as much space as possible (e.g.
the horizontal direction of a slider).
- \value MinimumExpanding The sizeHint() is minimal, and sufficient.
+ \value MinimumExpanding The tqsizeHint() is minimal, and sufficient.
The widget can make use of extra space, so it should get as much
space as possible (e.g. the horizontal direction of a slider).
- \value Ignored the sizeHint() is ignored. The widget will get as
+ \value Ignored the tqsizeHint() is ignored. The widget will get as
much space as possible.
*/
@@ -1475,13 +1475,13 @@ bool TQLayout::activate()
any direction.
\value Horizontally the widget can usefully be wider than the
- sizeHint().
+ tqsizeHint().
\value Vertically the widget can usefully be taller than the
- sizeHint().
+ tqsizeHint().
\value BothDirections the widget can usefully be both wider and
- taller than the sizeHint().
+ taller than the tqsizeHint().
*/
/*!
@@ -1543,7 +1543,7 @@ bool TQLayout::activate()
\fn bool TQSizePolicy::mayShrinkHorizontally() const
Returns TRUE if the widget can sensibly be narrower than its
- sizeHint(); otherwise returns FALSE.
+ tqsizeHint(); otherwise returns FALSE.
\sa mayShrinkVertically() mayGrowHorizontally()
*/
@@ -1552,7 +1552,7 @@ bool TQLayout::activate()
\fn bool TQSizePolicy::mayShrinkVertically() const
Returns TRUE if the widget can sensibly be shorter than its
- sizeHint(); otherwise returns FALSE.
+ tqsizeHint(); otherwise returns FALSE.
\sa mayShrinkHorizontally() mayGrowVertically()
*/
@@ -1561,7 +1561,7 @@ bool TQLayout::activate()
\fn bool TQSizePolicy::mayGrowHorizontally() const
Returns TRUE if the widget can sensibly be wider than its
- sizeHint(); otherwise returns FALSE.
+ tqsizeHint(); otherwise returns FALSE.
\sa mayGrowVertically() mayShrinkHorizontally()
*/
@@ -1570,7 +1570,7 @@ bool TQLayout::activate()
\fn bool TQSizePolicy::mayGrowVertically() const
Returns TRUE if the widget can sensibly be taller than its
- sizeHint(); otherwise returns FALSE.
+ tqsizeHint(); otherwise returns FALSE.
\sa mayGrowHorizontally() mayShrinkVertically()
*/
@@ -1579,7 +1579,7 @@ bool TQLayout::activate()
\fn TQ_SPExpandData TQSizePolicy::expandingDirections() const
Returns whether this tqlayout can make use of more space than
- sizeHint(). A value of \c Vertical or \c Horizontal means that it wants
+ tqsizeHint(). A value of \c Vertical or \c Horizontal means that it wants
to grow in only one dimension, whereas \c BothDirections means that
it wants to grow in both dimensions.
@@ -1847,7 +1847,7 @@ TQGLayoutIterator::~TQGLayoutIterator()
height-for-width (hasHeightForWidth()), this is
the same as \c Minimium; otherwise, this is the
same as \c FreeResize.
- \value Fixed The main widget's size is set to sizeHint(); it
+ \value Fixed The main widget's size is set to tqsizeHint(); it
cannot be resized at all.
\value Minimum The main widget's minimum size is set to
tqminimumSize(); it cannot be smaller.
@@ -1953,7 +1953,7 @@ void TQLayout::setAutoAdd( bool b )
layouts.
If \a b is TRUE, margin handling needs to be implemented in
- setGeometry(), tqmaximumSize(), tqminimumSize(), sizeHint() and
+ setGeometry(), tqmaximumSize(), tqminimumSize(), tqsizeHint() and
heightForWidth().
\sa supportsMargin()
@@ -1968,12 +1968,12 @@ void TQLayout::setSupportsMargin( bool b )
this tqlayout is set to \a r, provided that this tqlayout supports
tqsetAlignment().
- The result is derived from sizeHint() and expandingDirections(). It is never
+ The result is derived from tqsizeHint() and expandingDirections(). It is never
larger than \a r.
*/
TQRect TQLayout::alignmentRect( const TQRect &r ) const
{
- TQSize s = sizeHint();
+ TQSize s = tqsizeHint();
int a = tqalignment();
/*
@@ -1390,7 +1390,7 @@ bool TQLayout::activate()
if (ms.isValid())
mw->setMinimumSize( ms );
- // ideally only if sizeHint() or sizePolicy() has changed
+ // ideally only if tqsizeHint() or sizePolicy() has changed
mw->updateGeometry();
return TRUE;